@@ -1,10 +1,7 @@
-from sifflet.apis import client
+import client
 from sifflet.configure.service import SiffletConfig
 from sifflet.errors import config_needed_handler
 
-DEFAULT_PAGE_NUM = 0
-DEFAULT_ITEMS_PER_PAGE = 15
-
 
 class BaseApi:
     @config_needed_handler
