@@ -1,4 +1,5 @@
 from sifflet.configure.service import SiffletConfig
+from sifflet.errors import exception_handler
 from sifflet.ingest.api import ApiIngestion
 
 
@@ -7,5 +8,6 @@ class IngestionService:
         self.sifflet_config: SiffletConfig = sifflet_config
         self.api_ingestion = ApiIngestion(sifflet_config)
 
-    def ingest_dbt(self, project_name:str, target:str, input_folder:str):
-        self.api_ingestion.send_dbt_metadata(project_name, target, input_folder)
+    @exception_handler
+    def ingest_dbt(self, project_name: str, target: str, input_folder: str) -> bool:
+        return self.api_ingestion.send_dbt_metadata(project_name, target, input_folder)
