@@ -4,18 +4,18 @@ import click
 from rich.logging import RichHandler
 
 
-def get_logger() -> logging:
+def get_logger() -> logging.Logger:
     """
     Returns a logger with the specified name.
     """
     logging.basicConfig(
         level=logging.INFO,
         format="%(message)s",
-        datefmt=" ",
+        datefmt="%X",
         handlers=[RichHandler(rich_tracebacks=True, tracebacks_suppress=[click], markup=True)],
     )
 
     return logging.getLogger("sifflet")
 
 
-logger = get_logger()
+logger: logging.Logger = get_logger()
